@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 from .core import Base
-from .user import User
+from .user import User, EnterpriseUser
 from .tenant import Tenant
 
 __all__ = [
     'Base',
-    'User',
+    'User', 'EnterpriseUser',
     'Tenant'
 ]
